package com.chelvc.cloud.admin.controller;
import com.chelvc.cloud.vehicle.api.dto.FeedBackDTO;
import com.chelvc.cloud.vehicle.api.dto.GoodsDTO;
import com.chelvc.cloud.vehicle.api.param.FeedBackModifyParam;
import com.chelvc.cloud.vehicle.api.param.FeedBackPagingParam;
import com.chelvc.cloud.vehicle.api.param.GoodsPagingParam;
import com.chelvc.cloud.vehicle.api.service.FeedbackService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 意见反馈接口
 *
 * @author liude
 * @date 2023/1/16
 */
@Validated
@RestController
@ResponseWrapping
public class FeedbackController {
    @DubboReference
    private FeedbackService feedbackService;

    /**
     * 查询意见反馈
     */
    @GetMapping("/feedback/query")
    public List<FeedBackDTO> queryById(@Valid @NotEmpty String channel) {
        return this.feedbackService.getFeedback(channel);
    }

    /**
     * 查询意见反馈分页
     *
     * @param param 查询参数
     * @return 查询意见反馈分页信息
     */
    @GetMapping("/feedback/paging")
    public Pagination<FeedBackDTO> getFeedbackPaging(@Valid FeedBackPagingParam param) {
        return this.feedbackService.getFeedbackPaging(param);
    }



}
