package com.chelvc.cloud.admin.controller;

import com.chelvc.cloud.vehicle.api.dto.ReservationDTO;
import com.chelvc.cloud.vehicle.api.param.ReservationPagingParam;
import com.chelvc.cloud.vehicle.api.service.ReservationService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import javax.validation.constraints.Min;

/**
 * 预约管理接口
 *
 * @author liude
 * @Date 2023/1/19
 **/
@Validated
@RestController
@ResponseWrapping
public class ReservationController {
    @DubboReference
    private ReservationService reservationService;

    /**
     * 查询预约管理分页
     *
     * @param param 查询参数
     * @return 预约管理分页信息
     */
    @GetMapping("/reservation/paging")
    public Pagination<ReservationDTO> getReservationPaging(@Valid ReservationPagingParam param) {
        return this.reservationService.getReservationPaging(param);
    }

    /**
     * 更新预约单的状态
     * @param id 预约单ID
     * @param status 预约单的状态
     */
    @PutMapping("/updateReservationsStatus/{id}")
    public void updateReservationsStatus(@PathVariable("id") @Min(value = 1, message = "主键不能小于1") Long id, @Valid String status) {
        this.reservationService.updateReservationsStatus(id, status);
    }
}
